<?php
/**
 * A factory class for network packages
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class PackageFilterChainFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a filter chain by given tags array.
	 *
	 * @param	$tags			An array with tags from a package
	 * @return	$chainInstance	An instance of a filter chain class
	 */
	public static final function createChainByTagsArray (array $tags) {
		// Get a registry key from tags array, this does mostly call implode()
		$registryKey = Registry::getRegistryKeyFromArray('package_filter_chain', $tags);

		// Is the registry key there?
		if (Registry::getRegistry()->instanceExists($registryKey)) {
			// Yes, then use that instance
			$chainInstance = Registry::getRegistry()->getInstance($registryKey);
		} else {
			// Initialize a filter chain class
			$chainInstance = self::createObjectByConfiguredName('package_filter_chain_class');

			// "Walk" through all tags entries
			foreach ($tags as $tag) {
				/*
				 * Now create a filter instance of this tag. This way all tags
				 * got rudymentary verified, if an exception is coming here, it
				 * simply means the tag is not valid. This however should be
				 * handled some calls before this method is called.
				 */
				$filterInstance = self::createObjectByConfiguredName('package_tag_' . $tag . '_filter');

				// Add this filter to the chain
				$chainInstance->addFilter($filterInstance);
			} // END - foreach

			// Add filter for handling hash to miner queue
			$filterInstance = self::createObjectByConfiguredName('package_hash_to_miner_filter');

			// Add this filter to the chain
			$chainInstance->addFilter($filterInstance);

			// Add the finished chain to the registry
			Registry::getRegistry()->addInstance($registryKey, $chainInstance);
		}

		// Return the chain instance
		return $chainInstance;
	}
}

// [EOF]
?>
