<?php
/**
 * A factory class for DHT objects
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class DhtObjectFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton (registry-based) DHT object instance
	 *
	 * @param	$prefix			Prefix for DHT class name and registry key
	 * @return	$dhtInstance	An instance of a DHT object class
	 */
	public static final function createDhtInstance ($prefix) {
		// Set instance name
		$name = $prefix . '_dht';

		// If there is no handler?
		if (Registry::getRegistry()->instanceExists($name)) {
			// Get handler from registry
			$dhtInstance = Registry::getRegistry()->getInstance($name);
		} else {
			// Get the handler instance
			$dhtInstance = self::createObjectByConfiguredName($name . '_class');

			// Add it to the registry
			Registry::getRegistry()->addInstance($name, $dhtInstance);
		}

		// Return the instance
		return $dhtInstance;
	}
}

// [EOF]
?>
