<?php
/**
 * A ListenerPool shutdown visitor
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class ShutdownListenerPoolVisitor extends BaseVisitor implements PoolVisitor {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set visitor mode
		$this->setVisitorMode('shutdown');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$visitorInstance	An instance a Visitorable class
	 */
	public static final function createShutdownListenerPoolVisitor () {
		// Get new instance
		$visitorInstance = new ShutdownListenerPoolVisitor();

		// Return the prepared instance
		return $visitorInstance;
	}

	/**
	 * Visits the given pool instance
	 *
	 * @param	$poolInstance	A Poolable instance
	 * @return	void
	 */
	public function visitPool (Poolable $poolInstance) {
		// Debug message
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: Visit of ' . $poolInstance->__toString() . ' - CALLED!');

		// Pre-shutdown the pool
		$poolInstance->preShutdown();

		// Debug message
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: Visit of ' . $poolInstance->__toString() . ' - EXIT!');
	}

	/**
	 * Visits the given decorator instance
	 *
	 * @param	$decoratorInstance	A Listenable decorator instance
	 * @return	void
	 */
	public function visitDecorator (Listenable $decoratorInstance) {
		// Debug message
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: Visit of ' . $decoratorInstance->__toString() . ' - CALLED!');

		// Pre-shutdown the pool
		$decoratorInstance->doShutdown();

		// Debug message
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: Visit of ' . $decoratorInstance->__toString() . ' - EXIT!');
	}

	/**
	 * Visits the given listener instance
	 *
	 * @param	$listenerInstance	A Listenable class instance
	 * @return	void
	 */
	public function visitListener (Listenable $listenerInstance) {
		// Debug message
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: Visit of ' . $listenerInstance->__toString() . ' - CALLED!');

		// Pre-shutdown the pool
		$listenerInstance->doShutdown();

		// Debug message
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('[' . __METHOD__ . ':' . __LINE__ . ' ]: Visit of ' . $listenerInstance->__toString() . ' - EXIT!');
	}
}

//
?>
